OC.L10N.register(
    "files_external",
    {
    "External storage" : "Külső tárolók",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Grant access" : "Megadom a hozzáférést",
    "Generate keys" : "Kulcsok generálása",
    "Error generating key pair" : "Hiba történt a kulcspár generálása közben",
    "All users. Type to select user or group." : "Összes felhasználó. Írj be egy felhasználót vagy csoportot.",
    "(group)" : "(csoport)",
    "Admin defined" : "Adminisztrátor definiálva",
    "Saved" : "Elmentve",
    "Empty response from the server" : "Üres válasz a szervertől",
    "Couldn't access. Please logout and login to activate this mount point" : "Nem férhető hozzá. Kérjük próbálj meg ki- és bejelentkezni a csatolási pont aktiválásához.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Nem sikerült lekérdezni az információkat az ownCloud szerverről: {code} {type}",
    "There was an error with message: " : "Hiba történt ezzel az üzenettel:",
    "External mount error" : "Külső csatolási hiba",
    "Username" : "Felhasználónév",
    "Password" : "Jelszó",
    "Save" : "Mentés",
    "%s" : "%s",
    "Access key" : "Hozzáférési kulcs",
    "Secret key" : "Titkos kulcs",
    "App key" : "App kulcs",
    "App secret" : "App titkos kulcs",
    "Client secret" : "Kliens titkos",
    "API key" : "API kulcs",
    "RSA public key" : "RSA publikus kulcs",
    "Public key" : "Publikus kulcs",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hosztnév",
    "Port" : "Port",
    "Region" : "Megye",
    "Enable SSL" : "SSL engedélyezése",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Távoli alkönyvtár",
    "Secure https://" : "Biztonságos https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Helyi",
    "Location" : "Hely",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Kiszolgáló",
    "Root" : "Gyökér",
    "SFTP with secret key login" : "SFTP titkos kulcs belépéssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Megosztás",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS OC belépéssel",
    "Username as share" : "Felhasználónév és megosztás",
    "Service name" : "Szolgáltatás neve",
    "Request timeout (seconds)" : "Időtúllépés (másodperc)",
    "<b>Note:</b> " : "<b>Megjegyzés:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Megjegyzés:</b> A cURL támogatás, a PHP-ban nincs engedélyezve vagy telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Megjegyzés:</b> %s nincs telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "No external storage configured" : "Nincs külső tároló beállítva.",
    "Name" : "Név",
    "Storage type" : "Tároló típusa",
    "Enable encryption" : "Titkosítás engedélyezése",
    "Enable previews" : "Előnézet engedélyezése",
    "Check for changes" : "Változások keresése",
    "Never" : "Soha",
    "Once every direct access" : "Minden közvetlen elérésnél",
    "External Storage" : "Külső tárolási szolgáltatások becsatolása",
    "Folder name" : "Mappanév",
    "Authentication" : "Azonisítás",
    "Configuration" : "Beállítások",
    "Available for" : "Elérhető számukra",
    "Add storage" : "Tároló becsatolása",
    "Advanced settings" : "Haladó beállítások",
    "Delete" : "Törlés",
    "Allow users to mount external storage" : "Külső tárolók engedélyezése a felhasználók részére",
    "Allow users to mount the following external storage" : "A felhasználók számára engedélyezett külső tárolók:",
    "Disable external storage" : "Külső tároló kikapcsolása",
    "Error configuring OAuth1" : "Hiba történt az OAuth1 konfigurálásakor",
    "Invalid mount point" : "Érvénytelen csatolási pont",
    "Please provide a valid app key and secret." : "Kérjük, adjon meg egy érvényes felhasználási kulcsot és titkosítást.",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitás Mac NFD kódolással (lassú)"
},
"nplurals=2; plural=(n != 1);");
